==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Private_Messages/language/lang-portuguese.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_EMAIL","Email");
define("_RE","Re");
define("_SUBJECT","Ttulo");
define("_PRIVATEMESSAGES","Suas Mensagens Privadas");
define("_CHECKALL","Verificar Todas");
define("_FROM","De");
define("_DATE","Data");
define("_DONTHAVEMESSAGES","Voc no possui nenhuma mensagem");
define("_NOTREAD","No Lida");
define("_MSGSTATUS","Status da Mensagem");
define("_PRIVATEMESSAGE","Mensagem Privada");
define("_INDEX","ndice");
define("_SENT","Enviar");
define("_PREVIOUSMESSAGE","Mensagens Anteriores");
define("_NEXTMESSAGE","Mensagens Posteriores");
define("_PROFILE","Perfil");
define("_ABOUTPOSTING","Sobre a Postagem");
define("_ALLREGCANPOST","Todos os utilizadores registado podem enviar mensagens privadas");
define("_TO","Para");
define("_MESSAGEICON","cone da Mensagem");
define("_MESSAGE","Mensagem");
define("_HTML","HTML");
define("_PMON","Ligado");
define("_PMOFF","Desligado");
define("_BBCODE","BBCdigo");
define("_WROTE","escreveu");
define("_OPTIONS","Opes");
define("_HTMLDISSABLE","Desactivar HTML neste envio");
define("_BBCODEDISSABLE","Desactivar <a href=\"bbcode_ref.php\" target=\"_blank\"><i>BBCdifo</i></a> neste envio");
define("_SMILEDISSABLE","Desactivar <a href=\"bb_smilies.php\" target=\"_blank\"><i>sorrisos</i></a> neste envio");
define("_CANCELREPLY","Cancelar Resposta");
define("_CANCELSEND","Cancelar Envio");
define("_CLEAR","Limpar");
define("_SUBMIT","Enviar");
define("_USERNOTINDB","O utilizador selecionado no existe no nosso web site.");
define("_CHECKNAMEANDTRY","Por favor confira o nome e tente novamente.");
define("_MSGPOSTED","Sua mensagem foi enviada.");
define("_RETURNTOPMSG","Voc pode clicar aqui para actualizar sua caixa postal.");
define("_MSGDELETED","Suas mensagens foram excludas.");
define("_BBGO","go");
define("_BBNEWPMSG","New Messages");
define("_BBNONEWPMSG","No New Messages");
define("_BBTOTALPMSG","Total Messages");
define("_BBEMPTYPMSG","You don't have any Messages");
define("_BBLOGIN","Login to check your private message");
define("_BBPMSG","Private Message");
define("_BBINBOX","Inbox");
define("_BBSELECTFORUM","Select a Forum");
define("_BBNOFORUM","No More Forum");
define("_BBBANNED","Banned");
define("_CLICKSMILEBUTTONS","Click on the Smilies to insert it on your Message:");
define("_CLICKCODEBUTTONS","Click on the following buttons to add BBCode to your Message:");
define("_PRIVMSGERROR","Private Message Error!");
define("_USERDOESNTEXIST","Sorry, the selected user doesn't exist in our database")

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Private_Messages/language/lang-portuguese.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_EMAIL","Email");
define("_RE","Re");
define("_SUBJECT","Ttulo");
define("_PRIVATEMESSAGES","Suas Mensagens Privadas");
define("_CHECKALL","Verificar Todas");
define("_FROM","De");
define("_DATE","Data");
define("_DONTHAVEMESSAGES","Voc no possui nenhuma mensagem");
define("_NOTREAD","No Lida");
define("_MSGSTATUS","Status da Mensagem");
define("_PRIVATEMESSAGE","Mensagem Privada");
define("_INDEX","ndice");
define("_SENT","Enviar");
define("_PREVIOUSMESSAGE","Mensagens Anteriores");
define("_NEXTMESSAGE","Mensagens Posteriores");
define("_PROFILE","Perfil");
define("_ABOUTPOSTING","Sobre a Postagem");
define("_ALLREGCANPOST","Todos os utilizadores registado podem enviar mensagens privadas");
define("_TO","Para");
define("_MESSAGEICON","cone da Mensagem");
define("_MESSAGE","Mensagem");
define("_HTML","HTML");
define("_PMON","Ligado");
define("_PMOFF","Desligado");
define("_BBCODE","BBCdigo");
define("_WROTE","escreveu");
define("_OPTIONS","Opes");
define("_HTMLDISSABLE","Desactivar HTML neste envio");
define("_BBCODEDISSABLE","Desactivar <a href=\"bbcode_ref.php\" target=\"_blank\"><i>BBCdifo</i></a> neste envio");
define("_SMILEDISSABLE","Desactivar <a href=\"bb_smilies.php\" target=\"_blank\"><i>sorrisos</i></a> neste envio");
define("_CANCELREPLY","Cancelar Resposta");
define("_CANCELSEND","Cancelar Envio");
define("_CLEAR","Limpar");
define("_SUBMIT","Enviar");
define("_USERNOTINDB","O utilizador selecionado no existe no nosso web site.");
define("_CHECKNAMEANDTRY","Por favor confira o nome e tente novamente.");
define("_MSGPOSTED","Sua mensagem foi enviada.");
define("_RETURNTOPMSG","Voc pode clicar aqui para actualizar sua caixa postal.");
define("_MSGDELETED","Suas mensagens foram excludas.");
define("_BBGO","go");
define("_BBNEWPMSG","New Messages");
define("_BBNONEWPMSG","No New Messages");
define("_BBTOTALPMSG","Total Messages");
define("_BBEMPTYPMSG","You don't have any Messages");
define("_BBLOGIN","Login to check your private message");
define("_BBPMSG","Private Message");
define("_BBINBOX","Inbox");
define("_BBSELECTFORUM","Select a Forum");
define("_BBNOFORUM","No More Forum");
define("_BBBANNED","Banned");
define("_CLICKSMILEBUTTONS","Click on the Smilies to insert it on your Message:");
define("_CLICKCODEBUTTONS","Click on the following buttons to add BBCode to your Message:");
define("_PRIVMSGERROR","Private Message Error!");
define("_USERDOESNTEXIST","Sorry, the selected user doesn't exist in our database")

?>
